import 'package:cs_resources/generated/l10n.dart';
import 'package:flutter/material.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/util.dart';
import 'package:widgets/picker/option_pick_util.dart';

import '../../main/main_page.dart';
import '../create_success/feedback_create_success_page.dart';
import 'feedback_create_state.dart';

part 'feedback_create_view_model.g.dart';

@riverpod
class FeedbackCreateViewModel extends _$FeedbackCreateViewModel {
  @override
  FeedbackCreateState build() {
    final state = FeedbackCreateState(imgList: []);
    initListener(state);
    ref.onDispose(() {
      onDispose(state);
    });

    return state;
  }

  //选择选项
  void pickCategory() {
    _dismissKeyboard();

    OptionPickerUtil.showCupertinoOptionPicker(
      items: state.optionList,
      initialSelectIndex: 0,
      onPickerChanged: (_, index) {
        state = state.copyWith(selectedOption: state.optionList[index]);
      },
    );
  }

  void _dismissKeyboard() {
    final FocusNode titleFocusNode = state.formData['title']!['focusNode'];
    final FocusNode descFocusNode = state.formData['desc']!['focusNode'];
    titleFocusNode.unfocus();
    descFocusNode.unfocus();
  }

  ///提交反馈
  void submitFeedback() {
    state = state.copyWith(titleErrorText: null);

    _dismissKeyboard();

    final TextEditingController titleController = state.formData['title']!['controller'];
    final TextEditingController descController = state.formData['desc']!['controller'];

    final title = titleController.text;
    final desc = descController.text;

    Log.d('当前待提交的 option:${state.selectedOption} title:$title desc:$desc imgList:${state.imgList}');

    if (Utils.isEmpty(state.selectedOption)) {
      ToastEngine.show(S.current.choose_category);
      return;
    }

    if (Utils.isEmpty(title)) {
      state = state.copyWith(titleErrorText: "Title cannot be empty!");
      return;
    }

    //执行密码登录
    ToastEngine.show('准备执行请求 option:${state.selectedOption} title:$title desc:$desc imgList:${state.imgList}');

    //去成功页面
    FeedbackCreateSuccessPage.startInstance();
  }

  //选中图片
  void setImgList(List<String> list) {
    state = state.copyWith(imgList: list);
  }

  //初始化监听
  void initListener(FeedbackCreateState initState) {
    final FocusNode titleFocusNode = initState.formData['title']!['focusNode'];

    titleFocusNode.addListener(() {
      // 获取焦点的时候清空错误文本
      if (titleFocusNode.hasFocus) {
        state = state.copyWith(titleErrorText: null);
      }
    });
  }

  //销毁资源
  void onDispose(FeedbackCreateState initState) {
    final FocusNode titleFocusNode = initState.formData['title']!['focusNode'];
    titleFocusNode.dispose();

    Log.d("FeedbackCreateViewModel 销毁 onDispose");
  }
}
